SQLGetDiagRec

Function SQLGetDiagRec 

pub unsafe extern "system" fn SQLGetDiagRec(
    handle_type: HandleType,
    handle: Handle,
    RecNumber: i16,
    state: *mut Char,
    native_error_ptr: *mut i32,
    message_text: *mut Char,
    buffer_length: i16,
    text_length_ptr: *mut i16,
) -> SqlReturn
Return the current values of multiple fields of a diagnostic record that contains eror, warning, and status information.

Returns

SUCCESS, SUCCESS_WITH_INFO, ERROR, or INVALID_HANDLE