SqlDataType

Struct SqlDataType 

#[repr(C)]
pub struct SqlDataType(pub i16);

Tuple Fields

0: i16

Implementations

Source

impl SqlDataType

pub const UNKNOWN_TYPE: SqlDataType

pub const CHAR: SqlDataType

pub const NUMERIC: SqlDataType

pub const DECIMAL: SqlDataType

pub const INTEGER: SqlDataType

Exact numeric value with precision 10 and scale 0 (signed: -2[31] <= n <= 2[31] - 1, unsigned: 0 <= n <= 2[32] - 1). An application uses SQLGetTypeInfo or SQLColAttribute to determine whether a particular data type or a particular column in a result set is unsigned.

pub const SMALLINT: SqlDataType

pub const FLOAT: SqlDataType

pub const REAL: SqlDataType

pub const DOUBLE: SqlDataType

Signed, approximate, numeric value with a binary precision 53 (zero or absolute value 10[-308] to 10[308]).

pub const DATETIME: SqlDataType

pub const VARCHAR: SqlDataType

pub const DATE: SqlDataType

pub const TIME: SqlDataType

pub const TIMESTAMP: SqlDataType

Year, month, day, hour, minute, and second fields, with valid values as defined for the DATE and TIME data types.

pub const EXT_TIME_OR_INTERVAL: SqlDataType

pub const EXT_TIMESTAMP: SqlDataType

pub const EXT_LONG_VARCHAR: SqlDataType

pub const EXT_BINARY: SqlDataType

pub const EXT_VAR_BINARY: SqlDataType

pub const EXT_LONG_VAR_BINARY: SqlDataType

pub const EXT_BIG_INT: SqlDataType

pub const EXT_TINY_INT: SqlDataType

pub const EXT_BIT: SqlDataType

pub const EXT_W_CHAR: SqlDataType

pub const EXT_W_VARCHAR: SqlDataType

pub const EXT_W_LONG_VARCHAR: SqlDataType

pub const EXT_GUID: SqlDataType