SqlReturn

Struct SqlReturn 

#[repr(C)]
pub struct SqlReturn(pub i16);
Indicates the overall success or failure of the function

Each function in ODBC returns a code, known as its return code, which indicates the overall success or failure of the function. Program logic is generally based on return codes. See ODBC reference

Tuple Fields

0: i16

Implementations

Source

impl SqlReturn

pub const INVALID_HANDLE: SqlReturn

SQL_INVALID_HANDLE; Function failed due to an invalid environment, connection, statement, or descriptor handle.

This indicates a programming error. No additional information is available from SQLGetDiagRec or SQLGetDiagField. This code is returned only when the handle is a null pointer or is the wrong type, such as when a statement handle is passed for an argument a connection handle.

pub const ERROR: SqlReturn

Function failed

The application calls SQLGetDiagRec or SQLGetDiagField to retrieve additional information. The contents of any output arguments to the function are undefined.

pub const SUCCESS: SqlReturn

Function completed successfully

The application calls SQLGetDiagField to retrieve additional information from the header record.

pub const SUCCESS_WITH_INFO: SqlReturn

Function completed successfully, possibly with a nonfatal error (warning)

The application calls SQLGetDiagRec or SQLGetDiagField to retrieve additional information.

pub const STILL_EXECUTING: SqlReturn

A function that was started asynchronously is still executing

The application SQLGetDiagRec or SQLGetDiagField to retrieve additional information if any.

pub const NEED_DATA: SqlReturn

More data is needed

,such as when a parameter data is sent at execution time or additional connection information is required. The application calls SQLGetDiagRec or SQLGetDiagField to retrieve additional information, if any.

pub const NO_DATA: SqlReturn

No more data was available

The application calls SQLGetDiagRec or SQLGetDiagField to retrieve additional information. One or more driver-defined status records in class 02xxx may be returned.

pub const PARAM_DATA_AVAILABLE: SqlReturn