#[repr(u16)]pub enum InfoType {
Show 109 variants
MaxDriverConnections = 0,
MaxConcurrentActivities = 1,
DataSourceName = 2,
DriverName = 6,
DriverVer = 7,
ServerName = 13,
SearchPatternEscape = 14,
DbmsName = 17,
DbmsVer = 18,
AccessibleTables = 19,
AccessibleProcedures = 20,
ConcatNullBehavior = 22,
CursorCommitBehaviour = 23,
DataSourceReadOnly = 25,
DefaultTxnIsolation = 26,
ExpressionsInOrderBy = 27,
IdentifierCase = 28,
IdentifierQuoteChar = 29,
MaxColumnNameLen = 30,
MaxCursorNameLen = 31,
MaxSchemaNameLen = 32,
MaxCatalogNameLen = 34,
MaxTableNameLen = 35,
MultResultSets = 36,
OuterJoins = 38,
SchemaTerm = 39,
CatalogNameSeparator = 41,
CatalogTerm = 42,
ScrollOptions = 44,
TransactionCapable = 46,
UserName = 47,
ConvertFunctions = 48,
NumericFunctions = 49,
StringFunctions = 50,
SystemFunctions = 51,
TimedateFunctions = 52,
TransactionIsolationProtocol = 72,
Integrity = 73,
CorrelationName = 74,
NonNullableColumns = 75,
DriverOdbcVer = 77,
GetDataExtensions = 81,
SqlFileUsage = 84,
NullCollation = 85,
AlterTable = 86,
ColumnAlias = 87,
GroupBy = 88,
OrderByColumnsInSelect = 90,
SchemaUsage = 91,
CatalogUsage = 92,
SqlQuotedIdentifierCase = 93,
SpecialCharacters = 94,
Subqueries = 95,
UnionStatement = 96,
MaxColumnsInGroupBy = 97,
MaxColumnsInIndex = 98,
MaxColumnsInOrderBy = 99,
MaxColumnsInSelect = 100,
MaxColumnsInTable = 101,
MaxIndexSize = 102,
MaxRowSizeIncludesLong = 103,
MaxRowSize = 104,
MaxStatementLen = 105,
MaxTablesInSelect = 106,
MaxUserNameLen = 107,
TimedateAddIntervals = 109,
TimedateDiffIntervals = 110,
NeedLongDataLen = 111,
LikeEscapeClause = 113,
CatalogLocation = 114,
OuterJoinCapabilities = 115,
ActiveEnvironments = 116,
SqlConformance = 118,
BatchRowCount = 120,
BatchSupport = 121,
DynamicCursorAttributes1 = 144,
DynamicCursorAttributes2 = 145,
ForwardOnlyCursorAttributes1 = 146,
ForwardOnlyCursorAttributes2 = 147,
KeysetCursorAttributes1 = 150,
KeysetCursorAttributes2 = 151,
OdbcInterfaceConformance = 152,
ParamArrayRowCounts = 153,
ParamArraySelects = 154,
Sql92DatetimeFunctions = 155,
Sql92ForeignKeyDeleteRule = 156,
Sql92ForeignKeyUpdateRule = 157,
Sql92Grant = 158,
Sql92NumericValueFunctions = 159,
Sql92Predicates = 160,
Sql92RelationalJoinOperators = 161,
Sql92Revoke = 162,
Sql92RowValueConstructor = 163,
Sql92StringFunctions = 164,
Sql92ValueExpressions = 165,
StaticCursorAttributes1 = 167,
StaticCursorAttributes2 = 168,
AggregateFunctions = 169,
XopenCliYear = 10_000,
CursorSensitivity = 10_001,
DescribeParameter = 10_002,
CatalogName = 10_003,
CollationSeq = 10_004,
MaxIdentifierLen = 10_005,
AsyncMode = 10_021,
MaxAsyncConcurrentStatements = 10_022,
AsyncDbcFunctions = 10_023,
DriverAwarePoolingSupported = 10_024,
AsyncNotification = 10_025,
}Expand description
Information requested by SQLGetInfo
Variants
MaxDriverConnections = 0
MaxConcurrentActivities = 1
DataSourceName = 2
DriverName = 6
SQL_DRIVER_NAME. The name of the driver implementation file.
DriverVer = 7
SQL_DRIVER_VER. The version of the driver, in the form “MM.mm.rrrr”.
ServerName = 13
SearchPatternEscape = 14
DbmsName = 17
DbmsVer = 18
AccessibleTables = 19
AccessibleProcedures = 20
ConcatNullBehavior = 22
SQL_CONCAT_NULL_BEHAVIOR. How the data source handles concatenation of
NULL-valued character columns with non-NULL valued character columns.
CursorCommitBehaviour = 23
DataSourceReadOnly = 25
DefaultTxnIsolation = 26
ExpressionsInOrderBy = 27
SQL_EXPRESSIONS_IN_ORDERBY. Whether the data source supports expressions
in the ORDER BY list (“Y” or “N”).
IdentifierCase = 28
IdentifierQuoteChar = 29
MaxColumnNameLen = 30
MaxCursorNameLen = 31
MaxSchemaNameLen = 32
MaxCatalogNameLen = 34
MaxTableNameLen = 35
MultResultSets = 36
SQL_MULT_RESULT_SETS. Whether the data source supports multiple result
sets (“Y” or “N”).
OuterJoins = 38
SQL_OUTER_JOINS (ODBC 2.x). Replaced by OuterJoinCapabilities in
ODBC 3.x, but some Driver Managers still query this value.
SchemaTerm = 39
SQL_SCHEMA_TERM (also known as SQL_OWNER_TERM in ODBC 2.x). The data
source vendor’s name for a schema (e.g. “schema”, “owner”).
CatalogNameSeparator = 41
SQL_CATALOG_NAME_SEPARATOR (also known as SQL_QUALIFIER_NAME_SEPARATOR
in ODBC 2.x). The character used as a separator between a catalog name and
the qualified name element that follows or precedes it.
CatalogTerm = 42
SQL_CATALOG_TERM (also known as SQL_QUALIFIER_TERM in ODBC 2.x). The
data source vendor’s name for a catalog (e.g. “catalog”, “database”).
ScrollOptions = 44
SQL_SCROLL_OPTIONS C-API places this in the extended header. Lists the supported cursor
types (forward-only, static, keyset-driven, dynamic, or mixed). All data sources must
support forward-only cursors. See:
https://learn.microsoft.com/sql/odbc/reference/develop-app/determining-cursor-capabilities
TransactionCapable = 46
UserName = 47
ConvertFunctions = 48
SQL_CONVERT_FUNCTIONS. The scalar conversion functions supported by the
driver and data source (bitmask: SQL_FN_CVT_CAST, SQL_FN_CVT_CONVERT).
NumericFunctions = 49
SQL_NUMERIC_FUNCTIONS. The scalar numeric functions supported by the
driver and data source (bitmask).
StringFunctions = 50
SQL_STRING_FUNCTIONS. The scalar string functions supported by the driver
and data source (bitmask).
SystemFunctions = 51
SQL_SYSTEM_FUNCTIONS. The scalar system functions supported by the driver
and data source (bitmask).
TimedateFunctions = 52
SQL_TIMEDATE_FUNCTIONS. The scalar date and time functions supported by
the driver and data source (bitmask).
TransactionIsolationProtocol = 72
Integrity = 73
CorrelationName = 74
SQL_CORRELATION_NAME. Whether correlated table names are supported.
NonNullableColumns = 75
SQL_NON_NULLABLE_COLUMNS. Whether the data source supports NOT NULL in
columns.
DriverOdbcVer = 77
SQL_DRIVER_ODBC_VER. The version of ODBC that the driver supports, in
the form “MM.mm” (e.g. “03.80”).
GetDataExtensions = 81
SqlFileUsage = 84
SQL_FILE_USAGE. How a single-tier driver directly treats files in a data source.
SQL_FILE_NOT_SUPPORTED (not a single-tier driver), SQL_FILE_TABLE (files are
treated as tables, e.g. Xbase), or SQL_FILE_CATALOG (files are treated as full
catalogs/databases, e.g. Microsoft Access).
NullCollation = 85
AlterTable = 86
ColumnAlias = 87
SQL_COLUMN_ALIAS. Whether the data source supports column aliases
(“Y” or “N”).
GroupBy = 88
SQL_GROUP_BY. The relationship between the columns in the GROUP BY
clause and the nonaggregated columns in the select list.
OrderByColumnsInSelect = 90
SchemaUsage = 91
SQL_SCHEMA_USAGE (also known as SQL_OWNER_USAGE in ODBC 2.x). A
bitmask enumerating the statements in which schemas can be used.
CatalogUsage = 92
SQL_CATALOG_USAGE (also known as SQL_QUALIFIER_USAGE in ODBC 2.x). A
bitmask enumerating the statements in which catalogs can be used.
SqlQuotedIdentifierCase = 93
SQL_QUOTED_IDENTIFIER_CASE. Case sensitivity of quoted identifiers in SQL. Returns
SQL_IC_UPPER (not case-sensitive, stored uppercase), SQL_IC_LOWER (not case-sensitive,
stored lowercase), SQL_IC_SENSITIVE (case-sensitive, stored mixed case), or
SQL_IC_MIXED (not case-sensitive, stored mixed case).
SpecialCharacters = 94
Subqueries = 95
SQL_SUBQUERIES. A bitmask enumerating the predicates that support
subqueries.
UnionStatement = 96
SQL_UNION_STATEMENT (also known as SQL_UNION in ODBC 2.x). A bitmask
enumerating support for the UNION statement.
MaxColumnsInGroupBy = 97
MaxColumnsInIndex = 98
MaxColumnsInOrderBy = 99
MaxColumnsInSelect = 100
MaxColumnsInTable = 101
MaxIndexSize = 102
MaxRowSizeIncludesLong = 103
SQL_MAX_ROW_SIZE_INCLUDES_LONG. Whether the maximum row size returned
for MaxRowSize includes the length of all SQL_LONGVARCHAR and
SQL_LONGVARBINARY columns.
MaxRowSize = 104
MaxStatementLen = 105
MaxTablesInSelect = 106
MaxUserNameLen = 107
TimedateAddIntervals = 109
SQL_TIMEDATE_ADD_INTERVALS. A bitmask enumerating the timestamp
intervals supported by the TIMESTAMPADD scalar function.
TimedateDiffIntervals = 110
SQL_TIMEDATE_DIFF_INTERVALS. A bitmask enumerating the timestamp
intervals supported by the TIMESTAMPDIFF scalar function.
NeedLongDataLen = 111
SQL_NEED_LONG_DATA_LEN. Whether the data source needs the length of a
long data value before that value is sent to the data source (“Y” or “N”).
LikeEscapeClause = 113
SQL_LIKE_ESCAPE_CLAUSE. Whether the LIKE predicate supports an escape
character (“Y” or “N”).
CatalogLocation = 114
SQL_CATALOG_LOCATION (also known as SQL_QUALIFIER_LOCATION in ODBC
2.x). The position of the catalog in a qualified table name.
OuterJoinCapabilities = 115
ActiveEnvironments = 116
SQL_ACTIVE_ENVIRONMENTS C-API places this in the extended header. A u16 value that
specifies the maximum number of active environments that the driver can support. If there is
no specified limit or the limit is unknown, this value is set to zero.
SqlConformance = 118
SQL_SQL_CONFORMANCE. The level of SQL-92 supported by the driver.
BatchRowCount = 120
SQL_BATCH_ROW_COUNT. A bitmask enumerating the behavior of the driver
with respect to the availability of row counts.
BatchSupport = 121
SQL_BATCH_SUPPORT. A bitmask enumerating the driver’s support for
batches.
DynamicCursorAttributes1 = 144
SQL_DYNAMIC_CURSOR_ATTRIBUTES1 C-API places this in the extended header. Lists the fetch
types supported by scrollable cursors. The bits in the return value correspond to the fetch
types in SQLFetchScroll. See:
https://learn.microsoft.com/sql/odbc/reference/develop-app/determining-cursor-capabilities
DynamicCursorAttributes2 = 145
SQL_DYNAMIC_CURSOR_ATTRIBUTES2 C-API places this in the extended header. Lists whether
cursors can detect their own updates, deletes, and inserts. See:
https://learn.microsoft.com/sql/odbc/reference/develop-app/determining-cursor-capabilities
ForwardOnlyCursorAttributes1 = 146
SQL_FORWARD_ONLY_CURSOR_ATTRIBUTES1 C-API places this in the extended header. Lists the
fetch types supported by scrollable cursors. The bits in the return value correspond to the
fetch types in SQLFetchScroll. See:
https://learn.microsoft.com/sql/odbc/reference/develop-app/determining-cursor-capabilities
ForwardOnlyCursorAttributes2 = 147
SQL_FORWARD_ONLY_CURSOR_ATTRIBUTES2 C-API places this in the extended header. Lists
whether cursors can detect their own updates, deletes, and inserts. See:
https://learn.microsoft.com/sql/odbc/reference/develop-app/determining-cursor-capabilities
KeysetCursorAttributes1 = 150
SQL_KEYSET_CURSOR_ATTRIBUTES1 C-API places this in the extended header. Lists the fetch
types supported by scrollable cursors. The bits in the return value correspond to the fetch
types in SQLFetchScroll. See:
https://learn.microsoft.com/sql/odbc/reference/develop-app/determining-cursor-capabilities
KeysetCursorAttributes2 = 151
SQL_KEYSET_CURSOR_ATTRIBUTES2 C-API places this in the extended header. Lists whether
cursors can detect their own updates, deletes, and inserts. See:
https://learn.microsoft.com/sql/odbc/reference/develop-app/determining-cursor-capabilities
OdbcInterfaceConformance = 152
SQL_ODBC_INTERFACE_CONFORMANCE. The level of the ODBC 3.x interface that
the driver complies with.
ParamArrayRowCounts = 153
SQL_PARAM_ARRAY_ROW_COUNTS. A bitmask enumerating the driver’s
properties regarding the availability of row counts in a parameterized
execution.
ParamArraySelects = 154
SQL_PARAM_ARRAY_SELECTS. A bitmask enumerating the driver’s properties
regarding the availability of result sets in a parameterized execution.
Sql92DatetimeFunctions = 155
SQL_SQL92_DATETIME_FUNCTIONS. A bitmask enumerating the datetime scalar
functions supported per SQL-92.
Sql92ForeignKeyDeleteRule = 156
SQL_SQL92_FOREIGN_KEY_DELETE_RULE. Rules supported for a foreign key in
a DELETE statement, as defined in SQL-92.
Sql92ForeignKeyUpdateRule = 157
SQL_SQL92_FOREIGN_KEY_UPDATE_RULE. Rules supported for a foreign key in
an UPDATE statement, as defined in SQL-92.
Sql92Grant = 158
SQL_SQL92_GRANT. Clauses supported in the GRANT statement, as defined
in SQL-92.
Sql92NumericValueFunctions = 159
SQL_SQL92_NUMERIC_VALUE_FUNCTIONS. Numeric value scalar functions
supported per SQL-92.
Sql92Predicates = 160
SQL_SQL92_PREDICATES. Predicates supported in a SELECT statement, as
defined in SQL-92.
Sql92RelationalJoinOperators = 161
SQL_SQL92_RELATIONAL_JOIN_OPERATORS. Relational join operators supported
in a SELECT statement, as defined in SQL-92.
Sql92Revoke = 162
SQL_SQL92_REVOKE. Clauses supported in the REVOKE statement, as defined
in SQL-92.
Sql92RowValueConstructor = 163
SQL_SQL92_ROW_VALUE_CONSTRUCTOR. Row value constructor expressions
supported in a SELECT statement, as defined in SQL-92.
Sql92StringFunctions = 164
SQL_SQL92_STRING_FUNCTIONS. String scalar functions supported per
SQL-92.
Sql92ValueExpressions = 165
SQL_SQL92_VALUE_EXPRESSIONS. Value expressions supported, as defined in
SQL-92.
StaticCursorAttributes1 = 167
SQL_STATIC_CURSOR_ATTRIBUTES1 C-API places this in the extended header. Lists the fetch
types supported by scrollable cursors. The bits in the return value correspond to the fetch
types in SQLFetchScroll. See:
https://learn.microsoft.com/sql/odbc/reference/develop-app/determining-cursor-capabilities
StaticCursorAttributes2 = 168
SQL_STATIC_CURSOR_ATTRIBUTES2 C-API places this in the extended header. Lists whether
cursors can detect their own updates, deletes, and inserts. See:
https://learn.microsoft.com/sql/odbc/reference/develop-app/determining-cursor-capabilities
AggregateFunctions = 169
SQL_AGGREGATE_FUNCTIONS. A bitmask enumerating support for aggregation
functions.